=======
Credits
=======

Development Lead
----------------

* Jan C. Rivenaes <jriv@equinor.com>
* Hans Kallekleiv <hakal@equinor.com>
* Trine Alsos <tral@equinor.com>

Contributors
------------

None yet. Why not be the first?
